server_client_20141231_085104

### config1 : test_ordered_events

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 1.23875498772 sec | 4.10429501534 sec

Naarad report

### Metrics

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 113.58 | 113.58 | 113.58 | 113.58 | 113.58 | 113.58 | 113.58 | 113.58 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 4.0
server1-perf | latency | p50 lt 0.3 | 0.3535
server1-perf | latency | mean lt 0.33 | 0.62875
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 113.579
client1-perf | latency | mean lt 35.0 | 113.579
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None